==> vue-gtag-1.14.0.tgz: package/README.md <==
<p align="center">
  <img width="250" src="https://i.imgur.com/AlAf04U.png">
  <br>
  <a href="https://npm.im/vue-gtag">
    <img src="https://badgen.net/npm/v/vue-gtag">
  </a>
  <a href="https://npm.im/vue-gtag">
    <img src="https://badgen.net/npm/dw/vue-gtag?color=blue">
  </a>
  <a href="https://bundlephobia.com/result?p=vue-gtag">
    <img src="https://badgen.net/bundlephobia/minzip/vue-gtag">
  </a>
  <a href="https://circleci.com/gh/MatteoGabriele/workflows/vue-gtag/tree/master">
    <img src="https://badgen.net/circleci/github/MatteoGabriele/vue-gtag/master">
  </a>
  <a href="https://codeclimate.com/github/MatteoGabriele/vue-gtag/maintainability">
    <img src="https://badgen.net/codeclimate/maintainability/MatteoGabriele/vue-gtag?icon=codeclimate">
  </a>
  <a href="https://codeclimate.com/github/MatteoGabriele/vue-gtag/test_coverage">
    <img src="https://badgen.net/codeclimate/coverage/MatteoGabriele/vue-gtag?icon=codeclimate">
  </a>
</p>

# vue-gtag

Global Site Tag plugin for Vue

The global site tag (gtag.js) is a JavaScript tagging framework and API that allows you to send event data to Google Analytics, Google Ads, and Google Marketing Platform. For general gtag.js [documentation](https://developers.google.com/analytics/devguides/collection/gtagjs), read the gtag.js developer guide.

## Vue 3 update
Released Vue 3 compatible version on this new repo https://github.com/MatteoGabriele/vue-gtag-next and you can install the package under `vue-gtag-next`. I will release it under the `vue-gtag` package once Vue will officially release version 3 as latest version.
If you have any feedback, please consider opening an issue on https://github.com/MatteoGabriele/vue-gtag-next/issues :pray:

## Requirements

Vue ^2.0.0

## Install

```bash
npm install vue-gtag
```

## Documentation

- [vue-gtag documentation](https://matteo-gabriele.gitbook.io/vue-gtag/)
- [gtag.js official documentation](https://developers.google.com/analytics/devguides/collection/gtagjs)

## Issues and features requests

Please drop an issue, if you find something that doesn't work, or a feature request at [https://github.com/MatteoGabriele/vue-gtag/issues](https://github.com/MatteoGabriele/vue-gtag/issues)

Follow me on twitter [@matteo\_gabriele](https://twitter.com/matteo_gabriele) for updates

## Sponsors

<a href="https://www.homerun.co/">
  <img width="350" src="https://i.imgur.com/3bNzRy1.png" alt="Homerun.co">
</a>

==> vue-gtag-2.0.1.tgz: package/README.md <==
🔥 **HEADS UP!** This is version 2 branch and it requires Vue 3. If you are looking for a Vue 2 compatible version, use [version 1](https://github.com/MatteoGabriele/vue-gtag/tree/1.0). You can find both documentations [here](https://matteo-gabriele.gitbook.io/vue-gtag/) 


<p align="center">
  <img width="250" src="https://i.imgur.com/AlAf04U.png">
  <br>
  <a href="https://npm.im/vue-gtag">
    <img src="https://badgen.net/npm/v/vue-gtag">
  </a>
  <a href="https://npm.im/vue-gtag">
    <img src="https://badgen.net/npm/dw/vue-gtag?color=blue">
  </a>
  <a href="https://bundlephobia.com/result?p=vue-gtag">
    <img src="https://badgen.net/bundlephobia/minzip/vue-gtag">
  </a>
  <a href="https://circleci.com/gh/MatteoGabriele/workflows/vue-gtag/tree/master">
    <img src="https://badgen.net/circleci/github/MatteoGabriele/vue-gtag/master">
  </a>
  <a href="https://codeclimate.com/github/MatteoGabriele/vue-gtag/maintainability">
    <img src="https://badgen.net/codeclimate/maintainability/MatteoGabriele/vue-gtag?icon=codeclimate">
  </a>
  <a href="https://codeclimate.com/github/MatteoGabriele/vue-gtag/test_coverage">
    <img src="https://badgen.net/codeclimate/coverage/MatteoGabriele/vue-gtag?icon=codeclimate">
  </a>
</p>

# vue-gtag

Global Site Tag plugin for Vue

The global site tag (gtag.js) is a JavaScript tagging framework and API that allows you to send event data to Google Analytics, Google Ads, and Google Marketing Platform. For general gtag.js [documentation](https://developers.google.com/analytics/devguides/collection/gtagjs), read the gtag.js developer guide.

## Requirements

Vue ^3.0.0

## Install

```bash
npm install vue-gtag@next
```

## Documentation

- [vue-gtag documentation](https://matteo-gabriele.gitbook.io/vue-gtag/)
- [gtag.js official documentation](https://developers.google.com/analytics/devguides/collection/gtagjs)

## Issues and features requests

Please drop an issue, if you find something that doesn't work, or a feature request at [https://github.com/MatteoGabriele/vue-gtag/issues](https://github.com/MatteoGabriele/vue-gtag/issues)

Follow me on twitter [@matteo\_gabriele](https://twitter.com/matteo_gabriele) for updates

## Sponsors

<a href="https://www.homerun.co/">
  <img width="350" src="https://i.imgur.com/3bNzRy1.png" alt="Homerun.co">
</a>
